# Fastapi Storages

Collection of backend storages and orm extensions to simplify file management in fastapi projects. This project
is inspired by the [django-storages](https://github.com/jschneier/django-storages) packages. If you have  suggestion for a storage backend that is not 
yet supported, please [open an issue](https://github.com/Tobi-De/fastapi-storages/issues/new) and will discuss it.

[![PyPI](https://img.shields.io/pypi/v/fastapi-storages.svg)][pypi_]
[![Status](https://img.shields.io/pypi/status/fastapi-storages.svg)][status]
[![Python Version](https://img.shields.io/pypi/pyversions/fastapi-storages)][python version]
[![License](https://img.shields.io/pypi/l/fastapi-storages)][license]

[![Read the documentation at https://fastapi-storages.readthedocs.io/](https://img.shields.io/readthedocs/fastapi-storages/latest.svg?label=Read%20the%20Docs)][read the docs]
[![Tests](https://github.com/Tobi-De/fastapi-storages/workflows/Tests/badge.svg)][tests]
[![Codecov](https://codecov.io/gh/Tobi-De/fastapi-storages/branch/main/graph/badge.svg)][codecov]

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)][pre-commit]
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)][black]

[pypi_]: https://pypi.org/project/fastapi-storages/
[status]: https://pypi.org/project/fastapi-storages/
[python version]: https://pypi.org/project/fastapi-storages
[read the docs]: https://fastapi-storages.readthedocs.io/
[tests]: https://github.com/Tobi-De/fastapi-storages/actions?workflow=Tests
[codecov]: https://app.codecov.io/gh/Tobi-De/fastapi-storages
[pre-commit]: https://github.com/pre-commit/pre-commit
[black]: https://github.com/psf/black


## Features

### Media storage backend

- [ ] Local
- [ ] Amazon ses
- [ ] Google cloud
- [ ] Deta

### Database extensions

- [ ] Tortoise ORM
- [ ] RedisOM
- [ ] Beanie
- [ ] SQLModel

## Installation

You can install _Fastapi Storages_ via [pip] from [PyPI]:

```console
$ pip install fastapi-storages
```

## Quickstart

```python

```

## Contributing

Contributions are very welcome.
To learn more, see the [Contributor Guide].

## License

Distributed under the terms of the [MIT license][license],
_Fastapi Storages_ is free and open source software.

## Issues

If you encounter any problems,
please [file an issue] along with a detailed description.

## Credits

This project was generated from [@cjolowicz]'s [Hypermodern Python Cookiecutter] template.

[@cjolowicz]: https://github.com/cjolowicz
[pypi]: https://pypi.org/
[hypermodern python cookiecutter]: https://github.com/cjolowicz/cookiecutter-hypermodern-python
[file an issue]: https://github.com/Tobi-De/fastapi-storages/issues
[pip]: https://pip.pypa.io/

<!-- github-only -->

[license]: https://github.com/Tobi-De/fastapi-storages/blob/main/LICENSE
[contributor guide]: https://github.com/Tobi-De/fastapi-storages/blob/main/CONTRIBUTING.md
[command-line reference]: https://fastapi-storages.readthedocs.io/en/latest/usage.html
